@@ -1,20 +1,34 @@
 """
 Compute on- and off-periods from localization frames.
 
-Assuming that the provided localizations are acquired from the same label, we analyze the times of recording as
+Assuming that the provided localizations are acquired from the same label,
+we analyze the times of recording as
 provided by the `frame` property.
 """
-import logging
+from __future__ import annotations
 
+import logging
+import sys
+from collections.abc import Iterable, Sequence
+from typing import Any
+
+if sys.version_info >= (3, 11):
+    from typing import Self
+else:
+    from typing_extensions import Self
+
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
+import numpy.typing as npt
 import pandas as pd
 from scipy import stats
 
+from locan.analysis import metadata_analysis_pb2
 from locan.analysis.analysis_base import _Analysis, _list_parameters
 from locan.data.locdata import LocData
 
-__all__ = ["BlinkStatistics"]
+__all__: list[str] = ["BlinkStatistics"]
 
 logger = logging.getLogger(__name__)
 
@@ -22,35 +36,47 @@ logger = logging.getLogger(__name__)
 # The algorithms
 
 
-def _blink_statistics(locdata, memory=0, remove_heading_off_periods=True):
+def _blink_statistics(
+    locdata: LocData | npt.ArrayLike,
+    memory: int = 0,
+    remove_heading_off_periods: bool = True,
+) -> dict[str, npt.NDArray[np.int_ | np.float_] | list[int | float]]:
     """
     Estimate on and off times from the frame values provided.
 
-    On and off-periods and the first frame of each period are determined from the sorted frame values.
-    A series of frame values that constantly increase by one is considered a on-period.
-    Each series of missing frame values between two given frame values is considered an off-period.
+    On and off-periods and the first frame of each period are determined from
+    the sorted frame values.
+    A series of frame values that constantly increase by one is considered an
+    on-period.
+    Each series of missing frame values between two given frame values is
+    considered an off-period.
 
     Parameters
     ----------
-    locdata : LocData, array-like
+    locdata
         Localization data or just the frame values of given localizations.
-    memory : int
+    memory
         The maximum number of intermittent frames without any localization
         that are still considered to belong to the same on-period.
+    remove_heading_off_periods
+        Flag to indicate if off-periods at the beginning of the series are
+        excluded.
 
     Returns
     -------
-    dict with numpy.ndarray as values
+    dict[str, npt.NDArray[int | float] | list[int | float]]
         'on_periods' and 'off_periods' in units of frame numbers.
-        'on_periods_frame' and 'off_periods_frame' with the first frame in each on/off-period.
-        'on_periods_indices' are groups of indices to the input frames or more precise np.unique(frames)
+        'on_periods_frame' and 'off_periods_frame' with the first frame in
+        each on/off-period.
+        'on_periods_indices' are groups of indices to the input frames or
+        more precise np.unique(frames)
     """
     if isinstance(locdata, LocData):
         frames = locdata.data.frame.values
     else:
-        frames = locdata
+        frames = locdata  # type: ignore[assignment]
 
-    frames, counts = np.unique(frames, return_counts=True)
+    frames, counts = np.unique(frames, return_counts=True)  # type: ignore[call-overload]
 
     # provide warning if duplicate frames are found. This should not be the case for appropriate localization clusters.
     if np.any(counts > 1):
@@ -62,7 +88,7 @@ def _blink_statistics(locdata, memory=0, remove_heading_off_periods=True):
 
     # shift frames and add first frame if no zero frame present to account for initial off_period
     first_frame = frames[0]
-    frames_ = np.insert(frames + 1, 0, 0)
+    frames_ = np.insert(frames + 1, 0, 0)  # type: ignore[operator]
 
     differences = np.insert(
         np.diff(frames_), 0, 1
@@ -141,13 +167,17 @@ class BlinkStatistics(_Analysis):
     """
     Estimate on and off times from the frame values provided.
 
-    On and off-periods and the first frame of each period are determined from the sorted frame values.
-    A series of frame values that constantly increase by one is considered a on-period.
-    Each series of missing frame values between two given frame values is considered an off-period.
+    On and off-periods and the first frame of each period are determined from
+    the sorted frame values.
+    A series of frame values that constantly increase by one is considered an
+    on-period.
+    Each series of missing frame values between two given frame values is
+    considered an off-period.
 
     A log warning is provided if a frame number occurs multiple times.
 
-    Missing localizations within an on-period can be taken into account by increasing the `memory` parameter.
+    Missing localizations within an on-period can be taken into account by
+    increasing the `memory` parameter.
     There is no way to correct for false positive localizations.
 
     Parameters
@@ -156,48 +186,59 @@ class BlinkStatistics(_Analysis):
         The maximum number of intermittent frames without any localization
         that are still considered to belong to the same on-period.
     remove_heading_off_periods : bool
-        Flag to indicate if off-periods at the beginning of the series are excluded.
-    meta : locan.analysis.metadata_analysis_pb2.AMetadata
+        Flag to indicate if off-periods at the beginning of the series are
+        excluded.
+    meta : metadata_analysis_pb2.AMetadata | None
         Metadata about the current analysis routine.
 
     Attributes
     ----------
     count : int
         A counter for counting instantiations.
-    parameter : dict
+    parameter : dict[str, Any]
         A dictionary with all settings for the current computation.
-    meta : locan.analysis.metadata_analysis_pb2.AMetadata
+    meta : metadata_analysis_pb2.AMetadata
         Metadata about the current analysis routine.
-    results : dict with numpy.ndarray as values
+    results : dict[str, npt.NDArray[np.int_ | np.float_] | list[int | float]] | None
         'on_periods' and 'off_periods' in units of frame numbers.
-        'on_periods_frame' and 'off_periods_frame' with the first frame in each on/off-period.
-        'on_periods_indices' are groups of indices to the input frames or more precise np.unique(frames)
+        'on_periods_frame' and 'off_periods_frame' with the first frame in
+        each on/off-period.
+        'on_periods_indices' are groups of indices to the input frames or more
+         precise np.unique(frames)
+    distribution_statistics : dict[str, Any]
+        Distribution parameters derived from MLE fitting of results.
     """
 
     count = 0
 
-    def __init__(self, meta=None, memory=0, remove_heading_off_periods=True):
-        super().__init__(
-            meta, memory=memory, remove_heading_off_periods=remove_heading_off_periods
-        )
-        self.results = None
-        self.distribution_statistics = {}
+    def __init__(
+        self,
+        meta: metadata_analysis_pb2.AMetadata | None = None,
+        memory: int = 0,
+        remove_heading_off_periods: bool = True,
+    ) -> None:
+        parameters = self._get_parameters(locals())
+        super().__init__(**parameters)
 
-    def compute(self, locdata):
+        self.results: dict[
+            str, npt.NDArray[np.int_ | np.float_] | list[int | float]
+        ] | None = None
+        self.distribution_statistics: dict[str, Any] = {}
+
+    def compute(self, locdata: LocData | npt.ArrayLike) -> Self:
         """
         Run the computation.
 
         Parameters
         ----------
-        locdata : LocData, array-like
+        locdata
             Localization data or just the frame values of given localizations.
 
         Returns
         -------
-        Analysis class
-            Returns the Analysis class object (self).
+        Self
         """
-        if not len(locdata):
+        if not len(locdata):  # type: ignore
             logger.warning("Locdata is empty.")
             return self
 
@@ -206,31 +247,39 @@ class BlinkStatistics(_Analysis):
 
     def fit_distributions(
         self,
-        distribution=stats.expon,
-        data_identifier=("on_periods", "off_periods"),
-        with_constraints=True,
-        **kwargs,
-    ):
+        distribution: str | stats.rv_continuous = stats.expon,
+        data_identifier: str | Iterable[str] = ("on_periods", "off_periods"),
+        with_constraints: bool = True,
+        **kwargs: Any,
+    ) -> None:
         """
-        Fit probability density functions to the distributions of on- and off-periods in the results
-        using MLE (scipy.stats).
+        Fit probability density functions to the distributions of on- and
+        off-periods in the results using MLE (scipy.stats).
 
-        If with_constraints is true we put the following constraints on the fit procedure:
-        If distribution is expon then floc=np.min(self.analysis_class.results[self.loc_property].values).
+        If with_constraints is true we put the following constraints on the
+        fit procedure:
+        If distribution is expon then
+        floc=np.min(self.analysis_class.results[self.loc_property].values).
 
         Parameters
         ----------
-        distribution : str, scipy.stats.distribution
+        distribution
             Distribution model to fit.
-        data_identifier : str
-            String to identify the data in `results` for which to fit an appropriate distribution, here
+        data_identifier
+            String to identify the data in `results` for which to fit an
+            appropriate distribution, here
             'on_periods' or 'off_periods'. For True all are fitted.
-        with_constraints : bool
+        with_constraints
             Flag to use predefined constraints on fit parameters.
-        kwargs : dict
-            Other parameters are passed to the `scipy.stat.distribution.fit()` function.
+        kwargs
+            Other parameters are passed to the `scipy.stat.distribution.fit()`
+            function.
+
+        Returns
+        -------
+        None
         """
-        if not self:
+        if self.results is None:
             logger.warning("No results available to fit.")
         else:
             if isinstance(data_identifier, (tuple, list)):
@@ -248,41 +297,42 @@ class BlinkStatistics(_Analysis):
 
     def hist(
         self,
-        data_identifier="on_periods",
-        ax=None,
-        bins="auto",
-        log=True,
-        fit=True,
-        **kwargs,
-    ):
+        data_identifier: str = "on_periods",
+        ax: mpl.axes.Axes | None = None,
+        bins: int | Sequence[int | float] | str = "auto",
+        log: bool = True,
+        fit: bool | None = True,
+        **kwargs: Any,
+    ) -> mpl.axes.Axes:
         """
-        Provide histogram as :class:`matplotlib.axes.Axes` object showing hist(results).
+        Provide histogram as :class:`matplotlib.axes.Axes` object showing
+        hist(results).
 
         Parameters
         ----------
-        data_identifier : str
+        data_identifier
             'on_periods' or 'off_periods'.
-        ax : :class:`matplotlib.axes.Axes`
+        ax
             The axes on which to show the image
-        bins : float
+        bins
             Bin specifications (passed to :func:`matplotlib.hist`).
-        log : Bool
+        log
             Flag for plotting on a log scale.
-        fit: bool, None
-            Flag indicating if distribution fit is shown. The fit will only be computed if `distribution_statistics`
-             is None.
-        kwargs : dict
+        fit
+            Flag indicating if distribution fit is shown.
+            The fit will only be computed if `distribution_statistics` is None.
+        kwargs
             Other parameters passed to :func:`matplotlib.pyplot.hist`.
 
         Returns
         -------
-        :class:`matplotlib.axes.Axes`
+        matplotlib.axes.Axes
             Axes object with the plot.
         """
         if ax is None:
             ax = plt.gca()
 
-        if not self:
+        if self.results is None:
             return ax
 
         ax.hist(
@@ -314,38 +364,46 @@ class _DistributionFits:
     Handle for distribution fits.
 
     This class is typically instantiated by specific Analysis methods.
-    It holds the statistical parameters derived by fitting the result distributions using MLE (scipy.stats).
+    It holds the statistical parameters derived by fitting the result
+    distributions using MLE (scipy.stats).
     Statistical parameters are defined as described in
     :ref:(https://docs.scipy.org/doc/scipy/reference/tutorial/stats/continuous.html)
 
     Parameters
     ----------
-    analyis_class : Analysis object
+    analysis_class
         The analysis class with result data to fit.
-    distribution : str, scipy.stats.distribution
+    distribution
         Distribution model to fit.
-    data_identifier : str
-        String to identify the data in `results` for which to fit an appropriate distribution
+    data_identifier
+        String to identify the data in `results` for which to fit an
+        appropriate distribution
 
     Attributes
     ----------
-    analyis_class : Analysis object
+    analysis_class : _Analysis
         The analysis class with result data to fit.
-    distribution : str, scipy.stats.distribution
+    distribution : scipy.stats.rv_continuous
         Distribution model to fit.
     data_identifier : str
-        String to identify the data in `results` for which to fit an appropriate distribution
-    parameters : list of str
+        String to identify the data in `results` for which to fit an
+        appropriate distribution
+    parameters : list[str]
         Distribution parameters.
     """
 
-    def __init__(self, analysis_class, distribution, data_identifier):
-        self.analysis_class = analysis_class
-        self.distribution = distribution
-        self.data_identifier = data_identifier
-        self.parameters = []
+    def __init__(
+        self,
+        analysis_class: _Analysis,
+        distribution: str | stats.rv_continuous,
+        data_identifier: str,
+    ) -> None:
+        self.analysis_class: _Analysis = analysis_class
+        self.distribution: stats.rv_continuous = distribution
+        self.data_identifier: str = data_identifier
+        self.parameters: list[str] = []
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return representation of the _DistributionFits class."""
         param_dict = dict(
             analysis_class=self.analysis_class.__class__.__name__,
@@ -355,20 +413,26 @@ class _DistributionFits:
         param_string = ", ".join((f"{key}={val}" for key, val in param_dict.items()))
         return f"{self.__class__.__name__}({param_string})"
 
-    def fit(self, with_constraints=True, **kwargs):
+    def fit(self, with_constraints: bool = True, **kwargs: Any) -> None:
         """
-        Fit scipy.stats.distribution to analysis_class.results[data_identifier].
+        Fit scipy.stats.rv_continuous to analysis_class.results[data_identifier].
 
-        If with_constraints is true we put the following constraints on the fit procedure:
-        If distribution is expon then floc=np.min(self.analysis_class.results[self.data_identifier].values).
+        If with_constraints is true we put the following constraints on the
+        fit procedure:
+        If distribution is expon then
+        floc=np.min(self.analysis_class.results[self.data_identifier].values).
 
         Parameters
         ----------
-        with_constraints : bool
+        with_constraints
             Flag to use predefined constraints on fit parameters.
-        kwargs : dict
-            Other parameters are passed to the `scipy.stat.distribution.fit()` function.
+        kwargs
+            Other parameters are passed to the `scipy.stat.distribution.fit()`
+            function.
         """
+        if self.analysis_class.results is None:
+            raise ValueError("Compute results before fitting.")
+
         # set data
         if isinstance(self.analysis_class.results, pd.DataFrame):
             data = self.analysis_class.results[self.data_identifier].values
@@ -383,7 +447,7 @@ class _DistributionFits:
         if with_constraints and self.distribution == stats.expon:
             # MLE fit of exponential distribution with constraints
             fit_results = stats.expon.fit(
-                data, **dict(dict(floc=np.min(data)), **kwargs)
+                data, **dict(dict(floc=np.min(data)), **kwargs)  # type: ignore[arg-type]
             )
             for parameter, result in zip(self.parameters, fit_results):
                 setattr(self, parameter, result)
@@ -392,21 +456,21 @@ class _DistributionFits:
             for parameter, result in zip(self.parameters, fit_results):
                 setattr(self, parameter, result)
 
-    def plot(self, ax=None, **kwargs):
+    def plot(self, ax: mpl.axes.Axes | None = None, **kwargs: Any) -> mpl.axes.Axes:
         """
-        Provide plot as :class:`matplotlib.axes.Axes` object showing the probability distribution functions of fitted
-        results.
+        Provide plot as :class:`matplotlib.axes.Axes` object showing the
+        probability distribution functions of fitted results.
 
         Parameters
         ----------
-        ax : :class:`matplotlib.axes.Axes`
+        ax
             The axes on which to show the image.
-        kwargs : dict
+        kwargs
             Other parameters passed to :func:`matplotlib.pyplot.plot`.
 
         Returns
         -------
-        :class:`matplotlib.axes.Axes`
+        mpl.axes.Axes
             Axes object with the plot.
         """
         if ax is None:
@@ -434,6 +498,6 @@ class _DistributionFits:
 
         return ax
 
-    def parameter_dict(self):
+    def parameter_dict(self) -> dict[str, int | float]:
         """Dictionary of fitted parameters."""
         return {k: self.__dict__[k] for k in self.parameters}
