@@ -23,8 +23,13 @@ Submodules:
    cluster
    tracking
    metadata_utils
+   validation
 
 """
+from __future__ import annotations
+
+from importlib import import_module
+
 from locan.data.aggregate import *
 from locan.data.cluster import *
 from locan.data.filter import *
@@ -38,18 +43,27 @@ from locan.data.register import *
 from locan.data.rois import *
 from locan.data.tracking import *
 from locan.data.transform import *
+from locan.data.validation import *
 
-__all__ = []
-__all__.extend(aggregate.__all__)
-__all__.extend(cluster.__all__)
-__all__.extend(properties.__all__)
-__all__.extend(transform.__all__)
-__all__.extend(filter.__all__)
-__all__.extend(hulls.__all__)
-__all__.extend(locdata.__all__)
-__all__.extend(region.__all__)
-__all__.extend(region_utils.__all__)
-__all__.extend(register.__all__)
-__all__.extend(rois.__all__)
-__all__.extend(tracking.__all__)
-__all__.extend(metadata_utils.__all__)
+submodules: list[str] = [
+    "aggregate",
+    "cluster",
+    "filter",
+    "hulls",
+    "locdata",
+    "metadata_utils",
+    "properties",
+    "region",
+    "region_utils",
+    "register",
+    "rois",
+    "tracking",
+    "transform",
+    "validation",
+]
+
+__all__: list[str] = []
+
+for submodule in submodules:
+    module_ = import_module(name=f".{submodule}", package="locan.data")
+    __all__.extend(module_.__all__)
