@@ -12,10 +12,13 @@ Submodules:
    misc
    statistics
 """
+from __future__ import annotations
 
 from locan.data.properties.locdata_statistics import *
 from locan.data.properties.misc import *
 
-__all__ = []
-__all__.extend(misc.__all__)
+from . import locdata_statistics, misc
+
+__all__: list[str] = []
 __all__.extend(locdata_statistics.__all__)
+__all__.extend(misc.__all__)
