@@ -10,13 +10,20 @@ Submodules:
 .. autosummary::
    :toctree: ./
 
+   files
    locdata
    utilities
 
 """
+from __future__ import annotations
+
+from locan.locan_io import files, locdata, utilities
+
+from .files import *
 from .locdata import *
 from .utilities import *
 
-__all__ = []
+__all__: list[str] = []
+__all__.extend(files.__all__)
 __all__.extend(locdata.__all__)
 __all__.extend(utilities.__all__)
