@@ -16,12 +16,14 @@ See Also
 --------
 locan.tests.test
 """
+from __future__ import annotations
+
 import argparse
 
 from locan.tests import test as sc_test
 
 
-def _add_arguments(parser):
+def _add_arguments(parser: argparse.ArgumentParser) -> None:
     parser.add_argument(
         "pytest_args",
         nargs="?",
@@ -31,7 +33,7 @@ def _add_arguments(parser):
     )
 
 
-def main(args=None):
+def main(args: list[str] | None = None) -> None:
     parser = argparse.ArgumentParser(description="Run test suite.")
     _add_arguments(parser)
     returned_args = parser.parse_args(args)
