@@ -6,26 +6,33 @@ This module includes unit tests for all modules within the locan package.
 The tests are organized following the subpackage structure of locan.
 
 """
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from locan import ROOT_DIR
 
-__all__ = ["test"]
+if TYPE_CHECKING:
+    from pytest import ExitCode
+
+__all__: list[str] = ["test"]
 
 
-def test(args=None):
+def test(args: str | list[str] | None = None) -> int | ExitCode:
     """
     Running tests with pytest.
 
     Parameters
     ----------
-    args : str, list of str
+    args
         Parameters passed to :func:`pytest.main`
     """
     try:
         import pytest
-    except ImportError:
-        raise ImportError("Need pytest to run tests.")
+    except ImportError as exc:
+        raise ImportError("Need pytest to run tests.") from exc
 
-    extra_args = ["-m not gui and not visual and not requires_datasets"]
+    extra_args = ["-m not gui and not visual"]
 
     if args is None:
         pass  # extra_args = []
