@@ -39,7 +39,7 @@ def test_AlphaComplex_visual(locdata_2d):
     ]
     assert lengths == [8, 2, 0, 6, 2]
 
-    locdata_2d.data.plot(*locdata_2d.coordinate_labels, kind="scatter")
+    locdata_2d.data.plot(*locdata_2d.coordinate_properties, kind="scatter")
     for simp in ac_simplices_all:
         plt.plot(points[simp, 0], points[simp, 1], "-b")
     for simp in ac_simplices_interior:
@@ -350,6 +350,7 @@ def test_AlphaComplex_0():
     assert lengths == [0, 0, 0, 0, 0]
 
     triangles_all = alpha_complex.get_alpha_complex_triangles(alpha, type="all")
+
     assert len(triangles_all) == 0
 
     H = alpha_complex.graph_from_lines(alpha, type="regular")
