@@ -42,7 +42,7 @@ COMMENT_METADATA = metadata_pb2.Metadata(comment="some user comment")
 def test_LocData(df_simple, caplog):
     dat = LocData(dataframe=df_simple, meta=COMMENT_METADATA)
     assert len(dat) == 5
-    assert dat.coordinate_labels == ["position_x", "position_y"]
+    assert dat.coordinate_keys == ["position_x", "position_y"]
     assert dat.dimension == 2
     assert np.array_equal(dat.centroid, [2.0, 1.8])
     assert dat.centroid[0] == dat.properties["position_x"]
@@ -76,19 +76,71 @@ def test_LocData(df_simple, caplog):
     assert "circularity_im" in dat.properties
 
 
+def test_update_properties():
+    df_with_coordinates = pd.DataFrame.from_dict(
+        {
+            "position_y": np.arange(1, 3),
+        }
+    )
+
+    df_with_all = pd.DataFrame.from_dict(
+        {
+            "position_y": np.arange(1, 3),
+            "uncertainty": np.arange(1, 3),
+            "intensity": np.arange(1, 3),
+            "frame": np.arange(1, 3),
+        }
+    )
+
+    locdata = LocData.from_dataframe(df_with_coordinates)
+    assert locdata.properties == {
+        "localization_count": 2,
+        "position_y": 1.5,
+        "uncertainty_y": 0.5,
+        "region_measure_bb": 1,
+        "localization_density_bb": 2.0,
+        "subregion_measure_bb": 2,
+    }
+
+    locdata = LocData.from_dataframe(df_with_all)
+    assert locdata.properties == {
+        "localization_count": 2,
+        "position_y": 1.2,
+        "uncertainty_y": 0.32,
+        "intensity": 3,
+        "frame": 1,
+        "region_measure_bb": 1,
+        "localization_density_bb": 2.0,
+        "subregion_measure_bb": 2,
+    }
+
+    locdata = LocData.from_dataframe(df_with_all)
+    update_function = {"position_y": np.mean}
+    locdata = locdata._update_properties(update_function=update_function)
+    assert locdata.properties == {
+        "localization_count": 2,
+        "intensity": 3,
+        "frame": 1,
+        "position_y": 1.5,
+        "region_measure_bb": 1,
+        "localization_density_bb": 2.0,
+        "subregion_measure_bb": 2,
+    }
+
+
 def test_LocData_empty(df_empty):
     dat = LocData()
     assert dat.data.empty
     assert dat.properties == {"localization_count": 0, "region_measure_bb": 0}
     assert len(dat) == 0
-    assert dat.coordinate_labels == []
+    assert dat.coordinate_keys == []
     assert dat.dimension == 0
 
     dat = LocData(dataframe=df_empty)
     assert dat.data.empty
     assert dat.properties == {"localization_count": 0, "region_measure_bb": 0}
     assert len(dat) == 0
-    assert dat.coordinate_labels == []
+    assert dat.coordinate_keys == []
     assert dat.dimension == 0
     # hulls are tested with locdata fixtures further down.
 
@@ -100,7 +152,9 @@ def test_LocData_from_dataframe(df_simple):
     assert list(dat.properties.keys()) == [
         "localization_count",
         "position_x",
+        "uncertainty_x",
         "position_y",
+        "uncertainty_y",
         "region_measure_bb",
         "localization_density_bb",
         "subregion_measure_bb",
@@ -112,7 +166,7 @@ def test_LocData_from_dataframe(df_simple):
 def test_LocData_from_dataframe_empty(df_empty):
     dat = LocData.from_dataframe(dataframe=df_empty)
     assert len(dat) == 0
-    assert dat.coordinate_labels == []
+    assert dat.coordinate_keys == []
     # print(dat.data)
 
 
@@ -129,14 +183,14 @@ def test_LocData_from_coordinates():
     coordinates = [(200, 500), (200, 600), (900, 650), (1000, 600)]
     dat = LocData.from_coordinates(coordinates=coordinates, meta=COMMENT_METADATA)
     assert np.array_equal(dat.coordinates, np.asarray(coordinates))
-    assert all(item in ["position_x", "position_y"] for item in dat.coordinate_labels)
+    assert all(item in ["position_x", "position_y"] for item in dat.coordinate_keys)
     assert len(dat) == 4
     assert dat.meta.comment == COMMENT_METADATA.comment
 
     coordinates = np.array([(200, 500), (200, 600), (900, 650), (1000, 600)])
     dat = LocData.from_coordinates(coordinates=coordinates, meta=COMMENT_METADATA)
     assert np.array_equal(dat.coordinates, np.asarray(coordinates))
-    assert all(item in ["position_x", "position_y"] for item in dat.coordinate_labels)
+    assert all(item in ["position_x", "position_y"] for item in dat.coordinate_keys)
     assert len(dat) == 4
 
     dat = LocData.from_coordinates(
@@ -145,7 +199,7 @@ def test_LocData_from_coordinates():
         meta=dict(comment="special order"),
     )
     assert np.array_equal(dat.coordinates, np.asarray(coordinates))
-    assert all(item in ["position_x", "position_z"] for item in dat.coordinate_labels)
+    assert all(item in ["position_x", "position_z"] for item in dat.coordinate_keys)
     assert len(dat) == 4
 
     with pytest.raises(ValueError):
@@ -223,6 +277,8 @@ def test_LocData_from_collection(df_simple):
         "position_y",
         "region_measure_bb",
         "subregion_measure_bb",
+        "uncertainty_x",
+        "uncertainty_y",
     }
 
     with pytest.warns(UserWarning):
@@ -235,7 +291,10 @@ def test_LocData_from_collection(df_simple):
         "region_measure_bb",
         "subregion_measure_bb",
         "region_measure_ch",
+        "subregion_measure_ch",
         "localization_density_ch",
+        "uncertainty_x",
+        "uncertainty_y",
     }
 
     col.update_oriented_bounding_box_in_references()
@@ -252,6 +311,9 @@ def test_LocData_from_collection(df_simple):
         "region_measure_ch",
         "region_measure_obb",
         "subregion_measure_bb",
+        "subregion_measure_ch",
+        "uncertainty_x",
+        "uncertainty_y",
     }
     # print(col.properties)
 
@@ -270,8 +332,11 @@ def test_LocData_from_collection(df_simple):
         "region_measure_ch",
         "region_measure_obb",
         "subregion_measure_bb",
+        "subregion_measure_ch",
         "region_measure_as",
         "localization_density_as",
+        "uncertainty_x",
+        "uncertainty_y",
     }
 
     col.update_inertia_moments_in_references()
@@ -288,10 +353,13 @@ def test_LocData_from_collection(df_simple):
         "region_measure_ch",
         "region_measure_obb",
         "subregion_measure_bb",
+        "subregion_measure_ch",
         "region_measure_as",
         "localization_density_as",
         "circularity_im",
         "orientation_im",
+        "uncertainty_x",
+        "uncertainty_y",
     }
 
 
@@ -457,19 +525,15 @@ def test_LocData_projection(locdata_3d):
     new_coordinate_labels = "position_x"
     new_locdata = locdata.projection(coordinate_labels=new_coordinate_labels)
 
-    assert all(
-        label in new_coordinate_labels for label in new_locdata.coordinate_labels
-    )
+    assert all(label in new_coordinate_labels for label in new_locdata.coordinate_keys)
     assert new_locdata.dimension == 1
     assert len(new_locdata) == len(locdata)
 
-    # test with multiple coordinate_labels
+    # test with multiple coordinate_properties
     new_coordinate_labels = ["position_x", "position_y"]
     new_locdata = locdata.projection(coordinate_labels=new_coordinate_labels)
 
-    assert all(
-        label in new_coordinate_labels for label in new_locdata.coordinate_labels
-    )
+    assert all(label in new_coordinate_labels for label in new_locdata.coordinate_keys)
     assert new_locdata.dimension == len(new_coordinate_labels)
     assert len(new_locdata) == len(locdata)
 
@@ -513,7 +577,9 @@ def test_LocData_add_column_to_dataframe(df_simple):
             == [
                 "localization_count",
                 "position_x",
+                "uncertainty_x",
                 "position_y",
+                "uncertainty_y",
                 "region_measure_bb",
                 "localization_density_bb",
                 "subregion_measure_bb",
@@ -782,3 +848,59 @@ def test_locdata_print_meta(capfd, locdata_2d):
     captured = capfd.readouterr()
     for element in ["identifier", "creation_time", "source", "state", "element_count"]:
         assert element in captured.out
+
+
+def test_locdata_coordinate_labels(locdata_2d):
+    c_labels = locdata_2d.coordinate_keys
+    assert c_labels == ["position_x", "position_y"]
+    c_labels.append("other")
+    assert c_labels == ["position_x", "position_y", "other"]
+    c_labels = locdata_2d.coordinate_keys
+    assert c_labels == ["position_x", "position_y"]
+
+
+def test_locdata_uncertainty_labels(locdata_2d):
+    c_labels = locdata_2d.uncertainty_keys
+    assert c_labels == []
+    c_labels.append("other")
+    assert c_labels == ["other"]
+    c_labels = locdata_2d.uncertainty_keys
+    assert c_labels == []
+
+
+def test_update_properties_in_references(df_simple, caplog):
+    locdata = LocData(dataframe=df_simple)
+    other_locdata = LocData(dataframe=df_simple)
+    collection = LocData.from_collection([locdata, other_locdata])
+    collection.dataframe.index = [1, 3]
+
+    # test dict
+    new_collection = copy.deepcopy(collection)
+
+    new_properties = {"new_property": [111, 222]}
+
+    new_collection.update_properties_in_references(properties=new_properties)
+
+    for reference_ in new_collection.references:
+        assert "new_property" in reference_.properties
+    assert new_collection.data.index.tolist() == collection.data.index.tolist()
+    assert "new_property" in new_collection.data.columns
+    assert new_collection.data.new_property.tolist() == [111, 222]
+    for key, value in collection.properties.items():
+        assert value == new_collection.properties[key]
+
+    # test Series with custom index
+    new_collection = copy.deepcopy(collection)
+    new_properties = pd.Series(name="new_property", data=[111, 222])
+    new_properties.index = [3, 1]
+    with pytest.raises(ValueError):
+        new_collection.update_properties_in_references(properties=new_properties)
+
+    # test DataFrame with custom index
+    new_collection = copy.deepcopy(collection)
+    new_properties = pd.DataFrame.from_dict(
+        {"new_property": [111, 222], "new_property_2": [1111, 2222]}
+    )
+    new_properties.index = [3, 1]
+    with pytest.raises(ValueError):
+        new_collection.update_properties_in_references(properties=new_properties)
