@@ -1,5 +1,3 @@
-import pytest
-
 from locan import (
     EXTRAS_REQUIRE,
     HAS_DEPENDENCY,
@@ -8,6 +6,7 @@ from locan import (
     QtBindings,
     needs_package,
 )
+from locan.dependencies import _get_dependencies
 
 
 def test_IMPORT_NAMES():
@@ -17,6 +16,16 @@ def test_IMPORT_NAMES():
     assert IMPORT_NAMES.get(package, package) == "sklearn"
 
 
+def test__get_dependencies():
+    required_dependencies, extra_dependencies = _get_dependencies(package="locan")
+    assert required_dependencies
+    assert extra_dependencies
+    # print(required_dependencies, extra_dependencies)
+    required_dependencies, extra_dependencies = _get_dependencies(package="numpy")
+    assert len(required_dependencies) == 0
+    assert len(extra_dependencies) == 0
+
+
 def test_dependency_lists():
     assert len(INSTALL_REQUIRES) > 0
     assert len(INSTALL_REQUIRES) == len(set(INSTALL_REQUIRES))
@@ -34,7 +43,6 @@ def test_needs_package():
     assert callable(needs_package("numpy"))
 
 
-@pytest.mark.skipif(not HAS_DEPENDENCY["pytest"])
 @needs_package("pytest")
 def function_to_be_decorated():
     """This is documentation for function_to_be_decorated."""
