@@ -15,12 +15,15 @@ Submodules:
    utilities
 
 """
+from __future__ import annotations
+
+from locan.visualize.napari import render2d, render3d, utilities
 
 from .render2d import *
 from .render3d import *
 from .utilities import *
 
-__all__ = []
+__all__: list[str] = []
 __all__.extend(render2d.__all__)
 __all__.extend(render3d.__all__)
 __all__.extend(utilities.__all__)
